==> zio-aws-mediapackage_2.13-5.17.104.9-sources.jar: zio/aws/mediapackage/model/package.scala <==
package zio.aws.mediapackage
import zio.aws.mediapackage.model.primitives.__string
import zio.prelude.Subtype
import zio.aws.mediapackage.model.primitives.__integer.Type
package object model {
  import scala.jdk.CollectionConverters._
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.mediapackage.model.primitives.MaxResults.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.mediapackage.model.primitives.__boolean.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.mediapackage.model.primitives.__integer.Type
    object __string extends Subtype[String]
    type __string = zio.aws.mediapackage.model.primitives.__string.Type
  }
  type AdTriggers = List[zio.aws.mediapackage.model.AdTriggersElement]
  type Tags = Map[__string, __string]
  type __listOfChannel = List[zio.aws.mediapackage.model.Channel]
  type __listOfHarvestJob = List[zio.aws.mediapackage.model.HarvestJob]
  type __listOfHlsManifest = List[zio.aws.mediapackage.model.HlsManifest]
  type __listOfHlsManifestCreateOrUpdateParameters =
    List[zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters]
  type __listOfIngestEndpoint = List[zio.aws.mediapackage.model.IngestEndpoint]
  type __listOfOriginEndpoint = List[zio.aws.mediapackage.model.OriginEndpoint]
  type __listOf__PeriodTriggersElement =
    List[zio.aws.mediapackage.model.PeriodTriggersElement]
  type __listOf__string = List[__string]
  type __mapOf__string = Map[__string, __string]
}

==> zio-aws-mediapackage_3-5.17.104.2-sources.jar: zio/aws/mediapackage/model/package.scala <==
package zio.aws.mediapackage
import zio.aws.mediapackage.model.primitives.__string
import zio.prelude.Subtype
import zio.aws.mediapackage.model.primitives.__integer.Type
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object MaxResults extends Subtype[Int]
    type MaxResults = zio.aws.mediapackage.model.primitives.MaxResults.Type
    object __boolean extends Subtype[Boolean]
    type __boolean = zio.aws.mediapackage.model.primitives.__boolean.Type
    object __integer extends Subtype[Int]
    type __integer = zio.aws.mediapackage.model.primitives.__integer.Type
    object __string extends Subtype[String]
    type __string = zio.aws.mediapackage.model.primitives.__string.Type
  }
  type AdTriggers = List[zio.aws.mediapackage.model.AdTriggersElement]
  type Tags = Map[__string, __string]
  type __listOfChannel = List[zio.aws.mediapackage.model.Channel]
  type __listOfHarvestJob = List[zio.aws.mediapackage.model.HarvestJob]
  type __listOfHlsManifest = List[zio.aws.mediapackage.model.HlsManifest]
  type __listOfHlsManifestCreateOrUpdateParameters =
    List[zio.aws.mediapackage.model.HlsManifestCreateOrUpdateParameters]
  type __listOfIngestEndpoint = List[zio.aws.mediapackage.model.IngestEndpoint]
  type __listOfOriginEndpoint = List[zio.aws.mediapackage.model.OriginEndpoint]
  type __listOf__PeriodTriggersElement =
    List[zio.aws.mediapackage.model.PeriodTriggersElement]
  type __listOf__string = List[__string]
  type __mapOf__string = Map[__string, __string]
}
